@@ -60,6 +60,14 @@ def _gen_requestid():
     ).hexdigest()
 
 
+_decorates = decorate_all(
+    [
+        (tornado.web.asynchronous, "asynchronous"),  # should be the last
+    ]
+)
+
+
+@six.add_metaclass(_decorates)
 class RequestHandler(tornado.web.RequestHandler):
     """Base handler for request handle
 
